using UnityEngine;
using System.Collections;

public class Player : MonoBehaviour 
{
	OTSprite sprite;	
	CharacterController cc;
	
	public GameObject spawnPoint;
	public bool spawnCorrectly;
	
	public float movementSpeed = 10;
	public float ladderSpeed = 2;
	public float maxSpeed = 4;
	public float jumpSpeed = 10;
	public float airFriction = 0.1f;
	public float groundFriction = 0.4f;
	
	public Vector3 velocity;
	public bool isg;
	
	bool touchingLadder;
	public bool hasTorch = false; 
	GameObject torchObj;
	
	public bool freezePlayer;
	
	public bool shard1 = false;
	public bool shard2 = false;
	public bool shard3 = false;
	public bool hasHat = false;
	bool usedAirJump = false;
	
	void Start () 
	{
		sprite = gameObject.GetComponent<OTAnimatingSprite>();
		cc = gameObject.GetComponent<CharacterController>();
		iTween.CameraFadeAdd();
		
		if (spawnCorrectly)
			transform.position = spawnPoint.transform.position;
		
	}
	
	void Update () 
	{
		if (freezePlayer) return;
		
		isg = cc.isGrounded;
		
		float h = Input.GetAxis("Horizontal");
		float v = Input.GetAxis("Vertical");
		
		Vector3 movement = Vector3.zero;
		
		velocity += new Vector3(h * movementSpeed, 0f, 0f);
		
		if (h < 0f) 
		{
			if (hasTorch)
			{
				Vector3 temp = torchObj.transform.localPosition;
				temp.x = -Mathf.Abs(torchObj.transform.localPosition.x);
				torchObj.transform.localPosition = temp;
			}
			sprite.flipHorizontal = true;
		}
		else if (h > 0f)
		{
			if (hasTorch)
			{
				Vector3 temp = torchObj.transform.localPosition;
				temp.x = Mathf.Abs(torchObj.transform.localPosition.x);
				torchObj.transform.localPosition = temp;
			}
			sprite.flipHorizontal = false;
		}
		
		float friction = 0f;
		
		if (cc.isGrounded)
		{
			if (Input.GetButtonDown("Jump"))
			{
				velocity.y = jumpSpeed;
			}
			usedAirJump = false;
			friction = groundFriction;
		}
		else
		{
			if (hasHat && !usedAirJump && Input.GetButtonDown("Jump"))
			{
				velocity.y = jumpSpeed;
				usedAirJump = true;
			}
			
			friction = airFriction;
		}
		
		if (Mathf.Abs(velocity.x) > maxSpeed)
			velocity.x = Mathf.Sign(velocity.x) * maxSpeed;
		
		
		if (touchingLadder)
		{
			velocity.y = v * ladderSpeed;
		}
		else
		{
			velocity += Physics.gravity * Time.deltaTime;
		}
		
		
		velocity.x *= (1f - friction);
		
		movement = velocity;
		
				

		
		CollisionFlags cf = cc.Move(movement * Time.deltaTime);
		
		if (cf == CollisionFlags.Above && velocity.y > 0)
		{
			velocity.y *= -0.5f; // hit head and dampen
		}
		
		if (cc.isGrounded)
		{
			velocity.y = 0;
		}
	}
	
	void OnTriggerEnter(Collider other)
	{
		if (other.gameObject.tag == "Shard")
		{
			
			
			if (other.gameObject.name == "Shard1")
				shard1 = true;
			
			if (other.gameObject.name == "Shard2")
				shard2 = true;
			
			if (other.gameObject.name == "Shard3")
				shard3 = true;
			
			
			other.gameObject.SendMessage("Get", this);
		}
		
		if (other.gameObject.name == "Torch")
		{
			Debug.Log("torch get");
			
			GameObject torch = other.gameObject;
			GameObject anchor = GameObject.Find("TorchAnchor");
			hasTorch = true;
			torchObj = torch;
			torch.collider.enabled = false;
			
			torch.transform.parent = gameObject.transform;
			torch.transform.localPosition = anchor.transform.localPosition;
		}
		
		if (other.gameObject.name == "Hat")
		{
			GameObject hat = other.gameObject;
			GameObject anchor = GameObject.Find("HatAnchor");
			hasHat = true;
			hat.collider.enabled = false;
			
			Bob b = hat.GetComponent<Bob>();
			b.enabled = false;
			
			hat.transform.parent = gameObject.transform;
			hat.transform.localPosition = anchor.transform.localPosition;
		}
		
		if (other.gameObject.tag == "Ladder")
		{
			touchingLadder = true;
		}
		
		if (other.gameObject.name == "Cat")
		{
			GameObject explosion = other.gameObject.transform.GetChild(0).gameObject;
			
			explosion.particleEmitter.Emit();
			explosion.transform.parent = gameObject.transform;
			explosion.transform.localPosition = Vector3.zero;
			
			Destroy(other.gameObject);	
		}
	}
	
	void OnTriggerExit(Collider other)
	{
		if (other.gameObject.tag == "Ladder")
		{
			touchingLadder = false;
			velocity.y = 0;
		}
		
		if (other.gameObject.name == "EnterCave")
		{
			
			GameObject darkness = GameObject.Find("Darkness");
			GameObject light = GameObject.Find("CaveLight");
			
			if (transform.position.x < other.gameObject.transform.position.x)
			{
				if (hasTorch)
					light.renderer.enabled = true;
				else
				{
					//darkness.renderer.enabled = true;
					iTween.CameraFadeTo(1, 1);
				}
			}
			else
			{
				//darkness.renderer.enabled = false;
				light.renderer.enabled = false;
				iTween.CameraFadeTo(0, 1);
			}
			
		}
	}
}
